#[repr(C)]pub struct drm_amdgpu_heap_info {
pub total_heap_size: u64,
pub usable_heap_size: u64,
pub heap_usage: u64,
pub max_allocation: u64,
}Fields
total_heap_size: u64max. physical memory
usable_heap_size: u64Theoretical max. available memory in the given heap
heap_usage: u64Number of bytes allocated in the heap. This includes all processes and private allocations in the kernel. It changes when new buffers are allocated, freed, and moved. It cannot be larger than heap_size.
max_allocation: u64Theoretical possible max. size of buffer which could be allocated in the given heap